<?php

namespace Litecms\VideoArchive\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\VideoArchive\Models\VideoArchive;

class VideoArchivePolicy
{

    /**
     * Determine if the given user can view the video_archive.
     *
     * @param UserPolicyInterface $authUser
     * @param VideoArchive $video_archive
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, VideoArchive $video_archive)
    {
        if ($authUser->canDo('video_archive.video_archive.view') && $authUser->isAdmin()) {
            return true;
        }

        return $video_archive->user_id == user_id() && $video_archive->user_type == user_type();
    }

    /**
     * Determine if the given user can create a video_archive.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('video_archive.video_archive.create');
    }

    /**
     * Determine if the given user can update the given video_archive.
     *
     * @param UserPolicyInterface $authUser
     * @param VideoArchive $video_archive
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, VideoArchive $video_archive)
    {
        if ($authUser->canDo('video_archive.video_archive.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $video_archive->user_id == user_id() && $video_archive->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given video_archive.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, VideoArchive $video_archive)
    {
        return $video_archive->user_id == user_id() && $video_archive->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given video_archive.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, VideoArchive $video_archive)
    {
        if ($authUser->canDo('video_archive.video_archive.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given video_archive.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, VideoArchive $video_archive)
    {
        if ($authUser->canDo('video_archive.video_archive.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
